package com.jiuqi.sql;

import java.sql.SQLException;
import java.sql.ResultSetMetaData;

public final class DataTypes
{
    public static final int UNKNOWN = 0;
    public static final int BOOLEAN = 1;
    public static final int DATETIME = 2;
    public static final int DOUBLE = 3;
    public static final int INTEGER = 5;
    public static final int STRING = 6;
    @Deprecated
    public static final int AUTOINC = 7;
    public static final int LONG = 8;
    public static final int BLOB = 9;
    public static final int BIGDECIMAL = 10;
    public static final int CUSTOM_FIRST = 5000;
    
    private DataTypes() {
    }
    
    public static int fromJavaSQLType(final int javaSQLType) {
        switch (javaSQLType) {
            case -6:
            case 4:
            case 5: {
                return 5;
            }
            case -5: {
                return 8;
            }
            case -7: {
                return 1;
            }
            case -1:
            case 1:
            case 12:
            case 2005: {
                return 6;
            }
            case 2:
            case 3:
            case 6:
            case 7:
            case 8: {
                return 3;
            }
            case 91:
            case 93: {
                return 2;
            }
            case -4:
            case -3: {
                return 9;
            }
            default: {
                return 0;
            }
        }
    }
    
    public static int fromJavaSQLType(final ResultSetMetaData metadata, final int index) throws SQLException {
        final int sqlType = metadata.getColumnType(index);
        if ((sqlType == 2 || sqlType == 3) && metadata.getScale(index) == 0 && metadata.getPrecision(index) <= 10 && metadata.getPrecision(index) > 0) {
            return 5;
        }
        return fromJavaSQLType(sqlType);
    }
    
    public static int toJavaSQLType(final int dataType) {
        switch (dataType) {
            case 1: {
                return 16;
            }
            case 2: {
                return 91;
            }
            case 3:
            case 10: {
                return 8;
            }
            case 5: {
                return 4;
            }
            case 6: {
                return 12;
            }
            case 7: {
                return 4;
            }
            case 8: {
                return -5;
            }
            case 9: {
                return 2004;
            }
            default: {
                return 1111;
            }
        }
    }
    
    public static String dataTypeToString(final int dataType) {
        switch (dataType) {
            case 0: {
                return "unknown";
            }
            case 1: {
                return "boolean";
            }
            case 2: {
                return "datetime";
            }
            case 3: {
                return "double";
            }
            case 5: {
                return "integer";
            }
            case 6: {
                return "string";
            }
            case 7: {
                return "autoinc";
            }
            case 8: {
                return "long";
            }
            case 9: {
                return "blob";
            }
            case 10: {
                return "bigdecimal";
            }
            default: {
                return null;
            }
        }
    }
}
